local ensure_packer = function()
  local fn = vim.fn
  local install_path = fn.stdpath('data')..'/site/pack/packer/start/packer.nvim'
  if fn.empty(fn.glob(install_path)) > 0 then
    fn.system({'git', 'clone', '--depth', '1', 'https://github.com/wbthomason/packer.nvim', install_path})
    vim.cmd [[packadd packer.nvim]]
    return true
  end
  return false
end

local packer_bootstrap = ensure_packer()

return require('packer').startup(function(use)
  use 'wbthomason/packer.nvim'
  use {
    'williamboman/mason.nvim',
    run = ':MasonUpdate' -- :MasonUpdate updates registry contents
  }
  use 'NvChad/nvim-colorizer.lua'
  use 'windwp/nvim-autopairs'
  use 'nvim-tree/nvim-tree.lua'
  use 'nvim-tree/nvim-web-devicons'
  use {'akinsho/bufferline.nvim', tag = "*", requires = 'nvim-tree/nvim-web-devicons'}
--  use {'neoclide/coc.nvim', branch = 'release'}

  -- Themes
  use 'folke/tokyonight.nvim'

  -- Automatically set up your configuration after cloning packer.nvim
  -- Put this at the end after all plugins
  if packer_bootstrap then
    require('packer').sync()
  end

  --  mason setup
  require 'mason'.setup()

  -- colorizer setup
  require 'colorizer'.setup()

  -- autopairs setup
  require 'nvim-autopairs'.setup()

  -- nvim-tree setup
  require 'nvim-tree'.setup()

  -- bufferline setup
  require 'bufferline'.setup()
  
end)
